/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef ozzkh
#define ozzkh

#include <QSortFilterProxyModel>
#include <QSplitter>
#include "c\
on.h"

class QMenu;
class oszk : public QWidget
<%
	Q_OBJECT
	public:
		oszk(QWidget*, jelzpn*);
		jelzpn *kidlgz;
		QPixmap eler;
		int jlzpnt;

		void paintEvent(QPaintEvent*);

		QMenu *elodez;

		QAction *kitzjl;
		QAction *prmz;

		bool event(QEvent*);
		void mouseReleaseEvent(QMouseEvent*);
		void irnyjl(const QString&);

		void dragEnterEvent(QDragEnterEvent*);
		void dragMoveEvent(QDragMoveEvent*);
		void dropEvent(QDropEvent*);
		void dragLeaveEvent(QDragLeaveEvent*);

	signals:
		void jvsltz(const QString&, int);

	public slots:
		void kivalt(const zagv&);
		void vnl();
		void kket();
		void bprl(const QPoint&);
%>;

#endif

